@@ -155,7 +155,7 @@ MainWindow::initLogging ()
                         this     , SLOT(onCleanupLogsArray()));
     Q_ASSERT(rv); Q_UNUSED(rv);
 
-    setStatus("Using qgvdial version 0.2.705");
+    setStatus("Using qgvdial version 0.2.710");
 }//MainWindow::initLogging
 
 /** Log information to console and to log file
@@ -509,11 +509,11 @@ MainWindow::init ()
 
 #if MOSQUITTO_CAPABLE
     // Connect the signals from the Mosquitto thread
-    rv = connect (&mqThread , SIGNAL(sigUpdateInbox()),
-                  &oInbox   , SLOT  (refresh()));
+    rv = connect (&mqThread , SIGNAL(sigUpdateInbox(const QDateTime &)),
+                  &oInbox   , SLOT  (refresh(const QDateTime &)));
     Q_ASSERT(rv);
-    rv = connect (&mqThread , SIGNAL(sigUpdateContacts()),
-                  &oContacts, SLOT  (refreshContacts()));
+    rv = connect (&mqThread , SIGNAL(sigUpdateContacts(const QDateTime &)),
+                  &oContacts, SLOT  (refreshContacts(const QDateTime &)));
     Q_ASSERT(rv);
     rv = connect (&mqThread , SIGNAL(status(QString,int)),
                    this     , SLOT  (setStatus(QString,int)));
@@ -567,7 +567,6 @@ MainWindow::initQML ()
 
     // Initialize the QML view
     this->setSource (QUrl ("qrc:/Main.qml"));
-//    this->setResizeMode (QDeclarativeView::SizeRootObjectToView);
 
     this->setUsername ("example@gmail.com");
     this->setPassword ("hunter2 :p");
